| Title: | Performing Monte Carlo Expectation Maximization Random Forest Imputation for Biological Data |
|---|---|
| Description: | Perform missing value imputation for biological data using the random forest algorithm, the imputation aim to keep the original mean and standard deviation consistent after imputation. |
| Authors: | Mohamed Soudy [aut, cre] |
| Maintainer: | Mohamed Soudy <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.2 |
| Built: | 2026-05-12 06:08:40 UTC |
| Source: | https://github.com/cran/MERO |
The function is evaluate the imputed data sets based on the mean and standard deviation
EvalImp(Originaldata, ImputedSets ,Imputed.mean, Imputed.sd)EvalImp(Originaldata, ImputedSets ,Imputed.mean, Imputed.sd)
Originaldata |
data frame of original data containing the missing values |
ImputedSets |
list of imputed data frames |
Imputed.mean |
data frame of the means of the imputed data sets |
Imputed.sd |
data frame of the standard deviations of the imputed data sets |
The best data frame which mean and standard deviation are close to the original data
Mohamed Soudy [email protected]
The function is used to impute the missing data using Monte Carlo Expectation Maximization Random Forest Imputation
MERO(Data, ntree = 100, Nsets = 5)MERO(Data, ntree = 100, Nsets = 5)
Data |
a data matrix with missing values. The columns correspond to the variables and the rows to the observations. |
ntree |
number of trees to grow in each forest. |
Nsets |
number of simulations/ data sets to be generated. |
A list containing data sets and imputed means, and imputed standard deviation.
Mohamed Soudy [email protected]
The function is used to plot the correlation between the imputed mean and original mean
PlotCorrelateMean(OriginalMean, ImputedMean)PlotCorrelateMean(OriginalMean, ImputedMean)
OriginalMean |
means of the original data |
ImputedMean |
means of the imputed data |
The scatter plot
The function is used to calculate the root mean square error between two vectors
RMSE(Actual, Predicted)RMSE(Actual, Predicted)
Actual |
Vector of actual data |
Predicted |
vector of predicted data |
The root mean square error between the two input vectors
Mohamed Soudy [email protected]
RMSE(c(1,2,3), c(10,20,30))RMSE(c(1,2,3), c(10,20,30))